@@ -1,13 +1,8 @@
 #!/usr/bin/env python
 
-"""Tests PFS-related functionality"""
+"""Tests admin-related functionality"""
 
 import pytest
-import random
-import string
-import threading
-from io import BytesIO
-from collections import namedtuple
 
 import python_pachyderm
 from tests import util
@@ -19,6 +14,7 @@ def test_extract_restore():
     client.restore((python_pachyderm.RestoreRequest(op=op) for op in ops))
 
 
+@util.skip_if_below_pachyderm_version(1, 8, 8)
 def test_extract_pipeline_restore():
     client = python_pachyderm.Client()
     _, _, pipeline_name = util.create_test_pipeline(client, "test_extract_pipeline_restore")
